@@ -214,7 +214,7 @@ class ModInfo(MixinMeta):
                 # This is not the most optimal, but if you're hitting this, you are losing more time
                 # to every single check running on users than the occasional user info invoke
                 # We don't start by building this way, since the number of times we hit this should be
-                # infintesimally small compared to when we don't across all uses of Red.
+                # infinitesimally small compared to when we don't across all uses of Red.
                 continuation_string = _(
                     "and {numeric_number} more roles not displayed due to embed limits."
                 )
@@ -245,15 +245,25 @@ class ModInfo(MixinMeta):
         data.add_field(name=_("Joined Discord on"), value=created_on)
         data.add_field(name=_("Joined this server on"), value=joined_on)
         if role_str is not None:
-            data.add_field(name=_("Roles"), value=role_str, inline=False)
+            data.add_field(
+                name=_("Roles") if len(roles) > 1 else _("Role"), value=role_str, inline=False
+            )
         if names:
             # May need sanitizing later, but mentions do not ping in embeds currently
             val = filter_invites(", ".join(names))
-            data.add_field(name=_("Previous Names"), value=val, inline=False)
+            data.add_field(
+                name=_("Previous Names") if len(names) > 1 else _("Previous Name"),
+                value=val,
+                inline=False,
+            )
         if nicks:
             # May need sanitizing later, but mentions do not ping in embeds currently
             val = filter_invites(", ".join(nicks))
-            data.add_field(name=_("Previous Nicknames"), value=val, inline=False)
+            data.add_field(
+                name=_("Previous Nicknames") if len(nicks) > 1 else _("Previous Nickname"),
+                value=val,
+                inline=False,
+            )
         if voice_state and voice_state.channel:
             data.add_field(
                 name=_("Current voice channel"),
