@@ -1,7 +1,9 @@
 from collections import defaultdict, deque
+from typing import Optional
+from datetime import timedelta
 
 from redbot.core import commands, i18n, checks
-from redbot.core.utils.chat_formatting import box
+from redbot.core.utils.chat_formatting import box, humanize_timedelta
 
 from .abc import MixinMeta
 
@@ -28,11 +30,13 @@ class ModSettings(MixinMeta):
         warn_mention_spam = data["mention_spam"]["warn"]
         kick_mention_spam = data["mention_spam"]["kick"]
         ban_mention_spam = data["mention_spam"]["ban"]
+        strict_mention_spam = data["mention_spam"]["strict"]
         respect_hierarchy = data["respect_hierarchy"]
         delete_delay = data["delete_delay"]
         reinvite_on_unban = data["reinvite_on_unban"]
         dm_on_kickban = data["dm_on_kickban"]
         default_days = data["default_days"]
+        default_tempban_duration = data["default_tempban_duration"]
         msg = ""
         msg += _("Delete repeats: {num_repeats}\n").format(
             num_repeats=_("after {num} repeats").format(num=delete_repeats)
@@ -54,6 +58,11 @@ class ModSettings(MixinMeta):
             if ban_mention_spam
             else _("No")
         )
+        msg += (
+            _("Mention Spam Strict: All mentions will count including duplicates\n")
+            if strict_mention_spam
+            else _("Mention Spam Strict: Only unique mentions will count\n")
+        )
         msg += _("Respects hierarchy: {yes_or_no}\n").format(
             yes_or_no=_("Yes") if respect_hierarchy else _("No")
         )
@@ -74,6 +83,9 @@ class ModSettings(MixinMeta):
             )
         else:
             msg += _("Default message history delete on ban: Don't delete any\n")
+        msg += _("Default tempban duration: {duration}").format(
+            duration=humanize_timedelta(seconds=default_tempban_duration)
+        )
         await ctx.send(box(msg))
 
     @modset.command()
@@ -106,6 +118,34 @@ class ModSettings(MixinMeta):
         Manage the automoderation settings for mentionspam.
         """
 
+    @mentionspam.command(name="strict")
+    @commands.guild_only()
+    async def mentionspam_strict(self, ctx: commands.Context, enabled: bool = None):
+        """
+        Setting to account for duplicate mentions.
+
+        If enabled all mentions will count including duplicated mentions.
+        If disabled only unique mentions will count.
+
+        Use this command without any parameter to see current setting.
+        """
+        guild = ctx.guild
+        if enabled is None:
+            state = await self.config.guild(guild).mention_spam.strict()
+            if state:
+                msg = _("Mention spam currently accounts for multiple mentions of the same user.")
+            else:
+                msg = _("Mention spam currently only accounts for mentions of different users.")
+            await ctx.send(msg)
+            return
+
+        if enabled:
+            msg = _("Mention spam will now account for multiple mentions of the same user.")
+        else:
+            msg = _("Mention spam will only account for mentions of different users.")
+        await self.config.guild(guild).mention_spam.strict.set(enabled)
+        await ctx.send(msg)
+
     @mentionspam.command(name="warn")
     @commands.guild_only()
     async def mentionspam_warn(self, ctx: commands.Context, max_mentions: int):
@@ -141,7 +181,7 @@ class ModSettings(MixinMeta):
         await ctx.send(
             _(
                 "Autowarn for mention spam enabled. "
-                "Anyone mentioning {max_mentions} or more different people "
+                "Anyone mentioning {max_mentions} or more people "
                 "in a single message will be autowarned.\n{mismatch_message}"
             ).format(max_mentions=max_mentions, mismatch_message=mismatch_message)
         )
@@ -181,7 +221,7 @@ class ModSettings(MixinMeta):
         await ctx.send(
             _(
                 "Autokick for mention spam enabled. "
-                "Anyone mentioning {max_mentions} or more different people "
+                "Anyone mentioning {max_mentions} or more people "
                 "in a single message will be autokicked.\n{mismatch_message}"
             ).format(max_mentions=max_mentions, mismatch_message=mismatch_message)
         )
@@ -220,7 +260,7 @@ class ModSettings(MixinMeta):
         await ctx.send(
             _(
                 "Autoban for mention spam enabled. "
-                "Anyone mentioning {max_mentions} or more different people "
+                "Anyone mentioning {max_mentions} or more people "
                 "in a single message will be autobanned.\n{mismatch_message}"
             ).format(max_mentions=max_mentions, mismatch_message=mismatch_message)
         )
@@ -331,3 +371,30 @@ class ModSettings(MixinMeta):
                 days=days
             )
         )
+
+    @modset.command()
+    @commands.guild_only()
+    async def defaultduration(
+        self,
+        ctx: commands.Context,
+        *,
+        duration: commands.TimedeltaConverter(
+            minimum=timedelta(seconds=1), default_unit="seconds"
+        ),
+    ):
+        """Set the default time to be used when a user is tempbanned.
+
+        Accepts: seconds, minutes, hours, days, weeks
+        `duration` must be greater than zero.
+
+        Examples:
+            `[p]modset defaultduration 7d12h10m`
+            `[p]modset defaultduration 7 days 12 hours 10 minutes`
+        """
+        guild = ctx.guild
+        await self.config.guild(guild).default_tempban_duration.set(duration.total_seconds())
+        await ctx.send(
+            _("The default duration for tempbanning a user is now {duration}.").format(
+                duration=humanize_timedelta(timedelta=duration)
+            )
+        )
