@@ -76,6 +76,7 @@ class HelpSettings:
     verify_exists: bool = False
     tagline: str = ""
     delete_delay: int = 0
+    use_tick: bool = False
 
     # Contrib Note: This is intentional to not accept the bot object
     # There are plans to allow guild and user specific help settings
@@ -127,6 +128,7 @@ class HelpSettings:
             "\nHelp only shows commands which can be used: {verify_checks}"
             "\nHelp shows unusable commands when asked directly: {verify_exists}"
             "\nDelete delay: {delete_delay}"
+            "\nReact with a checkmark when help is sent via DM: {use_tick}"
             "{tagline_info}"
         ).format_map(data)
 
@@ -428,17 +430,17 @@ class RedHelpFormatter(HelpFormatterABC):
         offset += len(embed_dict["embed"]["description"])
         offset += len(embed_dict["embed"]["title"])
 
-        # In order to only change the size of embeds when neccessary for this rather
+        # In order to only change the size of embeds when necessary for this rather
         # than change the existing behavior for people uneffected by this
         # we're only modifying the page char limit should they be impacted.
         # We could consider changing this to always just subtract the offset,
         # But based on when this is being handled (very end of 3.2 release)
         # I'd rather not stick a major visual behavior change in at the last moment.
         if page_char_limit + offset > 5500:
-            # This is still neccessary with the max interaction above
+            # This is still necessary with the max interaction above
             # While we could subtract 100% of the time the offset from page_char_limit
             # the intent here is to shorten again
-            # *only* when neccessary, by the exact neccessary amount
+            # *only* when necessary, by the exact neccessary amount
             # To retain a visual match with prior behavior.
             page_char_limit = 5500 - offset
         elif page_char_limit < 250:
@@ -623,7 +625,10 @@ class RedHelpFormatter(HelpFormatterABC):
 
     @staticmethod
     async def help_filter_func(
-        ctx, objects: Iterable[SupportsCanSee], help_settings: HelpSettings, bypass_hidden=False,
+        ctx,
+        objects: Iterable[SupportsCanSee],
+        help_settings: HelpSettings,
+        bypass_hidden=False,
     ) -> AsyncIterator[SupportsCanSee]:
         """
         This does most of actual filtering.
@@ -775,7 +780,8 @@ class RedHelpFormatter(HelpFormatterABC):
                     )
                 else:
                     messages.append(msg)
-
+            if use_DMs and help_settings.use_tick:
+                await ctx.tick()
             # The if statement takes into account that 'destination' will be
             # the context channel in non-DM context, reusing 'channel_permissions' to avoid
             # computing the permissions twice.
@@ -800,7 +806,7 @@ class RedHelpFormatter(HelpFormatterABC):
             c = menus.DEFAULT_CONTROLS if len(pages) > 1 else {"\N{CROSS MARK}": menus.close_menu}
             # Allow other things to happen during menu timeout/interaction.
             asyncio.create_task(menus.menu(ctx, pages, c, message=m))
-            # menu needs reactions added manually since we fed it a messsage
+            # menu needs reactions added manually since we fed it a message
             menus.start_adding_reactions(m, c.keys())
 
 
