@@ -15,7 +15,8 @@ from .utils.common_filters import (
     filter_urls,
     escape_spoilers,
 )
-from .i18n import Translator
+from .utils.chat_formatting import pagify
+from .i18n import Translator, set_contextual_locales_from_guild
 
 from .generic_casetypes import all_generics
 
@@ -240,13 +241,13 @@ class Case:
         guild: discord.Guild,
         created_at: int,
         action_type: str,
-        user: Union[discord.User, int],
-        moderator: Optional[Union[discord.User, int]],
+        user: Union[discord.Object, discord.abc.User, int],
+        moderator: Optional[Union[discord.Object, discord.abc.User, int]],
         case_number: int,
         reason: str = None,
         until: int = None,
         channel: Optional[Union[discord.TextChannel, discord.VoiceChannel, int]] = None,
-        amended_by: Optional[Union[discord.User, int]] = None,
+        amended_by: Optional[Union[discord.Object, discord.abc.User, int]] = None,
         modified_at: Optional[int] = None,
         message: Optional[discord.Message] = None,
         last_known_username: Optional[str] = None,
@@ -256,12 +257,18 @@ class Case:
         self.created_at = created_at
         self.action_type = action_type
         self.user = user
+        if isinstance(user, discord.Object):
+            self.user = user.id
         self.last_known_username = last_known_username
         self.moderator = moderator
+        if isinstance(moderator, discord.Object):
+            self.moderator = moderator.id
         self.reason = reason
         self.until = until
         self.channel = channel
         self.amended_by = amended_by
+        if isinstance(amended_by, discord.Object):
+            self.amended_by = amended_by.id
         self.modified_at = modified_at
         self.case_number = case_number
         self.message = message
@@ -280,9 +287,12 @@ class Case:
         data.pop("case_number", None)
         # last username is set based on passed user object
         data.pop("last_known_username", None)
-
-        for item in list(data.keys()):
-            setattr(self, item, data[item])
+        for item, value in data.items():
+            if isinstance(value, discord.Object):
+                # probably expensive to call but meh should capture all cases
+                setattr(self, item, value.id)
+            else:
+                setattr(self, item, value)
 
         # update last known username
         if not isinstance(self.user, int):
@@ -333,11 +343,7 @@ class Case:
         title = "{}".format(
             _("Case #{} | {} {}").format(self.case_number, casetype.case_str, casetype.image)
         )
-
-        if self.reason:
-            reason = _("**Reason:** {}").format(self.reason)
-        else:
-            reason = _("**Reason:** Use the `reason` command to add it")
+        reason = _("**Reason:** Use the `reason` command to add it")
 
         if self.moderator is None:
             moderator = _("Unknown")
@@ -388,14 +394,25 @@ class Case:
                 user = f"[{translated}] ({self.user})"
             else:
                 user = f"{self.last_known_username} ({self.user})"
-            avatar_url = None
         else:
             user = escape_spoilers(
                 filter_invites(f"{self.user} ({self.user.id})")
             )  # Invites and spoilers get rendered even in embeds.
-            avatar_url = self.user.avatar_url
 
         if embed:
+            if self.reason:
+                reason = _("**Reason:** {}").format(self.reason)
+                if len(reason) > 2048:
+                    reason = (
+                        next(
+                            pagify(
+                                reason,
+                                delims=[" ", "\n"],
+                                page_length=2000,
+                            )
+                        )
+                        + "..."
+                    )
             emb = discord.Embed(title=title, description=reason)
             emb.set_author(name=user)
             emb.add_field(name=_("Moderator"), value=moderator, inline=False)
@@ -418,6 +435,19 @@ class Case:
             emb.timestamp = datetime.utcfromtimestamp(self.created_at)
             return emb
         else:
+            if self.reason:
+                reason = _("**Reason:** {}").format(self.reason)
+                if len(reason) > 1000:
+                    reason = (
+                        next(
+                            pagify(
+                                reason,
+                                delims=[" ", "\n"],
+                                page_length=1000,
+                            )
+                        )
+                        + "..."
+                    )
             user = filter_mass_mentions(filter_urls(user))  # Further sanitization outside embeds
             case_text = ""
             case_text += "{}\n".format(title)
@@ -427,7 +457,10 @@ class Case:
             if until and duration:
                 case_text += _("**Until:** {}\n**Duration:** {}\n").format(until, duration)
             if self.channel:
-                case_text += _("**Channel**: {}\n").format(self.channel.name)
+                if isinstance(self.channel, int):
+                    case_text += _("**Channel**: {} (Deleted)\n").format(self.channel)
+                else:
+                    case_text += _("**Channel**: {}\n").format(self.channel.name)
             if amended_by:
                 case_text += _("**Amended by:** {}\n").format(amended_by)
             if last_modified:
@@ -800,11 +833,12 @@ async def create_case(
     guild: discord.Guild,
     created_at: datetime,
     action_type: str,
-    user: Union[discord.User, discord.Member],
-    moderator: Optional[Union[discord.User, discord.Member]] = None,
+    user: Union[discord.Object, discord.abc.User, int],
+    moderator: Optional[Union[discord.Object, discord.abc.User, int]] = None,
     reason: Optional[str] = None,
     until: Optional[datetime] = None,
     channel: Optional[discord.TextChannel] = None,
+    last_known_username: Optional[str] = None,
 ) -> Optional[Case]:
     """
     Creates a new case.
@@ -818,19 +852,27 @@ async def create_case(
     guild: discord.Guild
         The guild the action was taken in
     created_at: datetime
-        The time the action occurred at
+        The time the action occurred at.
+        If naive `datetime` object is passed, it's treated as a local time
+        (similarly to how Python treats naive `datetime` objects).
     action_type: str
         The type of action that was taken
-    user: Union[discord.User, discord.Member]
+    user: Union[discord.Object, discord.abc.User, int]
         The user target by the action
-    moderator: Optional[Union[discord.User, discord.Member]]
+    moderator: Optional[Union[discord.Object, discord.abc.User, int]]
         The moderator who took the action
     reason: Optional[str]
         The reason the action was taken
     until: Optional[datetime]
-        The time the action is in effect until
+        The time the action is in effect until.
+        If naive `datetime` object is passed, it's treated as a local time
+        (similarly to how Python treats naive `datetime` objects).
     channel: Optional[discord.TextChannel]
         The channel the action was taken in
+    last_known_username: Optional[str]
+        The last known username of the user
+        Note: This is ignored if a Member or User object is provided
+        in the user field
     """
     case_type = await get_casetype(action_type, guild)
     if case_type is None:
@@ -861,10 +903,12 @@ async def create_case(
             amended_by=None,
             modified_at=None,
             message=None,
+            last_known_username=last_known_username,
         )
         await _config.custom(_CASES, str(guild.id), str(next_case_number)).set(case.to_json())
         await _config.guild(guild).latest_case_number.set(next_case_number)
 
+    await set_contextual_locales_from_guild(bot, guild)
     bot.dispatch("modlog_case_create", case)
     try:
         mod_channel = await get_modlog_channel(case.guild)
